| Summary: | icu_66.1.bb:do_make_icudata Segmentation Fault in Parallel Builds | ||
|---|---|---|---|
| Product: | [Build System, Metadata & Runtime] OE-Core | Reporter: | Hongxu Jia <hongxu.jia> |
| Component: | oe-core other | Assignee: | Ross Burton <ross.burton> |
| Status: | RESOLVED FIXED | QA Contact: | |
| Severity: | normal | ||
| Priority: | Medium+ | CC: | randy.macleod, richard.purdie, ross.burton, steve |
| Version: | unspecified | ||
| Target Milestone: | 3.2 M2 | ||
| Hardware: | x86 | ||
| OS: | Multiple | ||
| Whiteboard: | |||
| OS type for building Yocto: | --- | Type of Regression: | --- |
| Verified: | Documentation change: | No (bug/feature does not impact docs) | |
|
Description
Hongxu Jia
2020-04-15 00:12:25 UTC
With a simple google, similar issue of icu https://unicode-org.atlassian.net/browse/ICU-13595?attachmentOrder=asc&oldIssueView=true https://bugzilla.mozilla.org/show_bug.cgi?id=869406 https://sourceforge.net/p/icu/mailman/message/12529195/ (In reply to comment #1) > With a simple google, similar issue of icu > > https://unicode-org.atlassian.net/browse/ICU- > 13595?attachmentOrder=asc&oldIssueView=true > > https://bugzilla.mozilla.org/show_bug.cgi?id=869406 > > https://sourceforge.net/p/icu/mailman/message/12529195/ does disabling parallel make help ? Also seen here: https://autobuilder.yoctoproject.org/typhoon/#/builders/44/builds/1816 (step 3b) (In reply to comment #2) > (In reply to comment #1) > > With a simple google, similar issue of icu > > > > https://unicode-org.atlassian.net/browse/ICU- > > 13595?attachmentOrder=asc&oldIssueView=true > > > > https://bugzilla.mozilla.org/show_bug.cgi?id=869406 > > > > https://sourceforge.net/p/icu/mailman/message/12529195/ > > does disabling parallel make help ? I was trying it locally on wind river linux, if it works, I will send the fix to community --- a/meta/recipes-support/icu/icu_66.1.bb +++ b/meta/recipes-support/icu/icu_66.1.bb @@ -55,7 +55,7 @@ do_make_icudata_class-target () { LDFLAGS='${BUILD_LDFLAGS}' \ ICU_DATA_FILTER_FILE=${WORKDIR}/filter.json \ ./runConfigureICU Linux --with-data-packaging=archive - oe_runmake ${PARALLEL_MAKE} + oe_runmake install -Dm644 ${S}/data/out/icudt${ICU_MAJOR_VER}l.dat ${S}/data/in/icudt${ICU_MAJOR_VER}l.dat } I get intermittent failures on dunfell autobuilder builds of icu, likely related: https://errors.yoctoproject.org/Errors/Details/410500/ Hongxu: did disabling parallel make help? (In reply to comment #8) > Hongxu: did disabling parallel make help? Yes, the issue was not found any more We can add PARALLEL_MAKE_task-make-icudata = "" to the recipe to disable parallel make in this task. Execution time for the task goes from 31s to 328s which is my view is unacceptable though, we need to fix this properly. Hongxu, Could you (and Robert?) take a look at the build to try to find and fix the race condition? Actually Ross is going to work on it. Got a patch that removes the parallel building but also changes a lot of the build so the performance hit isn't as bad. Dropping the AB-INT tag since this is now disabled from the autobuilder perspective (but is still an issue we need to fix). oe-core df89e8d1136fd406ba35ae573e2cb0cfc88c6aad mostly fixed this. |